@@ -15,18 +15,21 @@
 /* reposonses for the dialog */
 enum {
    RES_START_PM=1,
-   RES_DIST_UPGRADER=2
+   RES_DIST_UPGRADER=2,
+   RES_ADDON_CD=3
 };
 
 /* Returnvalues from apt-cdrom-check:
     # 0 - no ubuntu CD
     # 1 - CD with packages 
     # 2 - dist-upgrader CD
+    # 3 - addon CD
 */
 enum {
    NO_CD, 
    CD_WITH_PACKAGES, 
-   CD_WITH_DISTUPGRADER
+   CD_WITH_DISTUPGRADER,
+   CD_WITH_ADDONS
 };
 
 static LibHalContext *hal_ctx;
@@ -69,6 +72,22 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
 			     RES_DIST_UPGRADER,
 			     NULL);
 
+      break;
+   case CD_WITH_ADDONS:
+      title = _("Addon volume detected");
+      markup = _("<span weight=\"bold\" size=\"larger\">"
+	    "A addon volume with software applications has "
+	    "been detected.</span>\n\n"
+	    "Would you like to view/install the content? ");
+      gtk_dialog_add_buttons(GTK_DIALOG(dialog), 
+			     GTK_STOCK_CANCEL,
+			     GTK_RESPONSE_REJECT,
+			     _("Start package manager"), 
+			     RES_START_PM,
+			     _("Start addon installer"), 
+			     RES_ADDON_CD,
+			     NULL);
+
       break;
    default:
       g_assert_not_reached();
@@ -79,12 +98,12 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
    gtk_message_dialog_set_markup(GTK_MESSAGE_DIALOG(dialog), markup);
 
    int res = gtk_dialog_run (GTK_DIALOG (dialog));
-   char *cmd;
+   char *cmd = NULL;
    switch(res) {
    gchar *argv[3];
    case RES_START_PM:
       cmd = g_strdup_printf("synaptic --add-cdrom %s",mount_point);
-      invoke_with_gksu(cmd, "/usr/share/applications/synaptic.desktop");
+      invoke_with_gksu(cmd, "/usr/share/applications/synaptic.desktop", FALSE);
       break;
    case RES_DIST_UPGRADER:
       argv[0] = "/usr/lib/update-notifier/cddistupgrader";
@@ -92,10 +111,15 @@ void distro_cd_detected(UpgradeNotifier *un, int cdtype, char *mount_point)
       argv[2] = NULL;
       g_spawn_async (NULL, argv, NULL, 0, NULL, NULL, NULL, NULL);
       break;
+   case RES_ADDON_CD:
+      cmd = g_strdup_printf("gnome-app-install --addon-cd=%s", mount_point);
+      invoke_with_gksu(cmd, "/usr/share/applications/gnome-app-installdesktop", FALSE);
+      break;
    default:
       /* do nothing */
       break;
    }
+   g_free(cmd);
    gtk_widget_destroy (dialog);
 }
 
