@@ -198,7 +198,16 @@ char* get_lang_code(gboolean short_form)
  */
 char *hook_file_lookup_i18n(struct rfc822_header *rfc822, char *field)
 {
-   gchar *s, *entry;
+   gchar *s, *entry, *text;
+
+   /* first check for langpacks, then i18n fields */
+   entry = rfc822_header_lookup(rfc822, "GettextDomain");
+   if(entry != NULL) {
+      text =  rfc822_header_lookup(rfc822, field);
+      s = dgettext(entry, text);
+      if(text != s)
+	 return s;
+   }
 
    /* try $field-$languagecode_$countrycode first */
    s = g_strdup_printf("%s-%s", field, get_lang_code(FALSE));
@@ -223,33 +232,14 @@ char *hook_file_lookup_i18n(struct rfc822_header *rfc822, char *field)
 
 char* hook_description_get_summary(struct rfc822_header *rfc822)
 {
-   char *description = hook_file_lookup_i18n(rfc822, "Name");
-
-   char *summary = g_strdup(description);
-   char *p = strchr(summary,'\n');
-   if(p != NULL)
-      *p = 0;
+   char *summary = hook_file_lookup_i18n(rfc822, "Name");
    return summary;
 }
 
 char* hook_description_get_description(struct rfc822_header *rfc822)
 {
    char *description = hook_file_lookup_i18n(rfc822, "Description");
-   char *newd, *p;
-
-   // look for the first \n, that's the summary
-   newd = p = g_strdup(description);
-   if(p == NULL)
-      return "";
-
-   // convert \n to ' '
-   while( (p=strchr(p,'\n')) != NULL) 
-	  *p = ' ';
-   // strip leading/trailing whitespace
-   g_strstrip(newd);
-
-   // return the rest
-   return newd;
+   return description;
 }
 
 /*
@@ -328,8 +318,6 @@ gboolean show_next_hook(TrayApplet *ta, GList *hooks)
    fclose(f);
    g_free(filename);
    g_free(s);
-   g_free(summary);
-   g_free(descr);
    rfc822_header_free_all(rfc822);
 
    /* mark the current hook file as seen */
@@ -489,6 +477,14 @@ gboolean is_hook_relevant(const gchar *hook_file)
    }
    fclose(f);
 
+   // check for DisplayIf test
+   b = rfc822_header_lookup(rfc822, "DisplayIf");
+   if(b != NULL) {
+      g_debug("found DisplayIf command: '%s'", b);
+      int exitc = system(b);
+      g_debug("'%s' returned: %i", b, exitc);
+      res = (exitc == 0);
+   }
 
    g_free(filename);
    rfc822_header_free_all(rfc822);
