@@ -61,19 +61,19 @@ static void tray_destroyed_cb(GtkWidget *widget, void *data);
 void invoke(gchar *cmd, gchar *desktop, gboolean with_gksu)
 {
    if(with_gksu)
-      invoke_with_gksu(cmd, desktop);
+      invoke_with_gksu(cmd, desktop, FALSE);
    else
       g_spawn_command_line_async(cmd, NULL);
 }
 
 void
-invoke_with_gksu(gchar *cmd, gchar *desktop)
+invoke_with_gksu(gchar *cmd, gchar *descr, gboolean whole_message)
 {
         //g_print("invoke_update_manager ()\n");
 	gchar *argv[5];
 	argv[0] = "/usr/bin/gksu";
-	argv[1] = "--desktop";
-	argv[2] = desktop;
+	argv[1] = whole_message ? "--message" : "--desktop";
+	argv[2] = descr;
 	argv[3] = cmd;
 	argv[4] = NULL;
 
@@ -167,7 +167,10 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
       //g_print("crashreport found\n");
       un->crashreport_pending = TRUE;
    }
-
+   if(strstr(info_uri, UNICAST_LOCAL_AVAHI_FILE)) {
+      //g_print("avahi disabled due to unicast .local domain\n");
+      un->unicast_local_avahi_pending = TRUE;
+   }
 }
 
 /*
@@ -179,6 +182,7 @@ monitor_cb(GnomeVFSMonitorHandle *handle,
  * - hook_pending: we have new upgrade hoook information
  * - reboot_pending: we need to reboot
  * - crashreport_pending: we have a new crashreport
+ * - unicast_local_avahi_pending: avahi got disabled due to a unicast .local domain
  *
  */
 gboolean file_monitor_periodic_check(gpointer data)
@@ -186,6 +190,10 @@ gboolean file_monitor_periodic_check(gpointer data)
 {
    UpgradeNotifier *un = (UpgradeNotifier *)data;
 
+   // we are not ready yet, wait for the next timeslice
+   if((un->update == NULL) || (un->reboot == NULL) || (un->crashreport == NULL))
+      return TRUE;
+
    // DPkg::Post-Invoke has written a stamp file, that means a install/remove
    // operation finished, we can show hooks/reboot notifications then
    if(un->dpkg_was_run) {
@@ -245,6 +253,12 @@ gboolean file_monitor_periodic_check(gpointer data)
       un->crashreport_pending = FALSE;
    }
 
+   if(un->unicast_local_avahi_pending) {
+      g_print("checking for disabled avahi due to unicast .local domain now\n");
+      avahi_disabled_check ();
+      un->unicast_local_avahi_pending = FALSE;
+   }
+
    // reset the bitfields (for the next "time-slice")
    un->dpkg_was_run = FALSE;
    un->apt_get_runing = FALSE;
@@ -294,6 +308,7 @@ gboolean monitor_init(UpgradeNotifier *un)
       "/var/lib/dpkg/status", 
       "/var/lib/update-notifier/dpkg-run-stamp", 
       REBOOT_FILE,
+      UNICAST_LOCAL_AVAHI_FILE,
       NULL};
    for(i=0;monitor_files[i] != NULL;i++) {
       res = gnome_vfs_monitor_add(&monitor_handle,
@@ -338,7 +353,7 @@ tray_icons_init(UpgradeNotifier *un)
 
    /* crashreport detected icon */
    un->crashreport = g_new0 (TrayApplet, 1);
-   trayapplet_create(un->crashreport, "crashreport-notifier");
+   trayapplet_create(un->crashreport, "apport");
    crashreport_tray_icon_init(un->crashreport);
 
    return FALSE; // for the tray_destroyed_cb
@@ -355,7 +370,7 @@ tray_destroyed_cb(GtkWidget *widget, void *data)
 // this function checks if the user is in the admin group
 // if there is no admin group, we return true becuase there
 // is no way to figure if the user is a admin or not
-static gboolean
+gboolean
 in_admin_group()
 {
    int i, ng = 0;
@@ -386,7 +401,7 @@ in_admin_group()
 
 static GOptionEntry entries[] = 
 {
-   { "debug-hooks", 0, 0, G_OPTION_ARG_INT, &HOOK_DEBUG, "Enable hooks debugging"},
+   { "debug-hooks", 0, 0, G_OPTION_ARG_NONE, &HOOK_DEBUG, "Enable hooks debugging"},
    { NULL }
 };
 
@@ -450,6 +465,9 @@ main (int argc, char *argv[])
 	// create the icons with a timeout
 	g_timeout_add(5000, (GSourceFunc)(tray_icons_init), un);
 
+        // initial check for avahi
+        avahi_disabled_check();
+
 	// init hal (needs to be done _after_ the icons are created)
 	/* setup hal so that inserted cdroms can be checked */
 	LibHalContext *hal_ctx = up_do_hal_init();
