@@ -28,15 +28,18 @@
 #define CLIPBOARD_NAME 	"UPGRADE_NOTIFIER_SELECTION"
 #define GCONF_KEY_DEFAULT_ACTION "/apps/update-notifier/default_action"
 #define GCONF_KEY_NO_UPDATE_NOTIFICATIONS "/apps/update-notifier/no_show_notifications"
+#define GCONF_KEY_APPORT_NOTIFICATIONS "/apps/update-notifier/show_apport_crashes"
 
 #define HOOKS_DIR "/var/lib/update-notifier/user.d/"
 #define CRASHREPORT_HELPER "/usr/share/apport/apport-checkreports"
 #define CRASHREPORT_REPORT_APP "/usr/share/apport/apport-gtk"
 #define CRASHREPORT_DIR "/var/crash/"
 #define REBOOT_FILE "/var/run/reboot-required"
+#define UNICAST_LOCAL_AVAHI_FILE "/var/run/avahi-daemon/disabled-for-unicast-local"
 
-void invoke_with_gksu(gchar *cmd, gchar *descr);
+void invoke_with_gksu(gchar *cmd, gchar *descr, gboolean whole_message);
 void invoke(gchar *cmd, gchar *desktop, gboolean with_gksu);
+gboolean in_admin_group();
 
 typedef struct _TrayApplet TrayApplet;
 struct _TrayApplet 
@@ -72,6 +75,7 @@ struct _UpgradeNotifier
    gboolean reboot_pending;
    gboolean hook_pending;
    gboolean crashreport_pending;
+   gboolean unicast_local_avahi_pending;
    time_t last_apt_action;
 
 };
