@@ -137,7 +137,7 @@ cb_action(GObject *self, void *user_data)
    TrayApplet *ta = user_data;
 	
    int i = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(self), "action"));
-   invoke_with_gksu (actions[i][0], _(actions[i][2]));
+   invoke (actions[i][0], _(actions[i][2]), actions[i][3]);
 
    UpdateTrayAppletPrivate *priv = (UpdateTrayAppletPrivate*)ta->user_data;
    gconf_client_set_int(priv->gconf, GCONF_KEY_DEFAULT_ACTION, i, NULL);
@@ -146,8 +146,9 @@ cb_action(GObject *self, void *user_data)
 void 
 cb_preferences(GObject *self, void *user_data)
 {
-   invoke_with_gksu("/usr/bin/software-properties",
-		    "/usr/share/applications/software-properties.desktop");    
+   invoke_with_gksu("/usr/bin/software-properties-gtk",
+		    "/usr/share/applications/software-properties.desktop",
+		    FALSE);    
 }
 
 void 
